summaryrefslogtreecommitdiffstats
path: root/kolourpaint
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
commit3c5631f74d1c75204f950140331e10f739082ee9 (patch)
treea2811ff6c81d3c771745cde47734e65b1da3d806 /kolourpaint
parent6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef (diff)
downloadtdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.tar.gz
tdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kolourpaint')
-rw-r--r--kolourpaint/kpcommandhistory.cpp8
-rw-r--r--kolourpaint/kpdocument.cpp18
-rw-r--r--kolourpaint/kpdocumentsaveoptions.cpp24
-rw-r--r--kolourpaint/kpdocumentsaveoptions.h24
-rw-r--r--kolourpaint/kpdocumentsaveoptionswidget.cpp12
-rw-r--r--kolourpaint/kpmainwindow.cpp22
-rw-r--r--kolourpaint/kpmainwindow.h4
-rw-r--r--kolourpaint/kpmainwindow_file.cpp30
-rw-r--r--kolourpaint/kpmainwindow_help.cpp4
-rw-r--r--kolourpaint/kpmainwindow_image.cpp8
-rw-r--r--kolourpaint/kpmainwindow_settings.cpp4
-rw-r--r--kolourpaint/kpmainwindow_text.cpp28
-rw-r--r--kolourpaint/kpmainwindow_tools.cpp8
-rw-r--r--kolourpaint/kpmainwindow_view.cpp20
-rw-r--r--kolourpaint/pixmapfx/kpeffectflatten.cpp8
-rw-r--r--kolourpaint/pixmapfx/kppixmapfx.cpp4
-rw-r--r--kolourpaint/widgets/kptooltoolbar.cpp4
-rw-r--r--kolourpaint/widgets/kptoolwidgetbase.cpp8
18 files changed, 119 insertions, 119 deletions
diff --git a/kolourpaint/kpcommandhistory.cpp b/kolourpaint/kpcommandhistory.cpp
index 6849ebf4..db865a70 100644
--- a/kolourpaint/kpcommandhistory.cpp
+++ b/kolourpaint/kpcommandhistory.cpp
@@ -413,8 +413,8 @@ void kpCommandHistoryBase::readConfig ()
#if DEBUG_KP_COMMAND_HISTORY
kdDebug () << "kpCommandHistoryBase::readConfig()" << endl;
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupUndoRedo);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupUndoRedo);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
setUndoMinLimit (cfg->readNumEntry (kpSettingUndoMinLimit, undoMinLimit ()));
setUndoMaxLimit (cfg->readNumEntry (kpSettingUndoMaxLimit, undoMaxLimit ()));
@@ -430,8 +430,8 @@ void kpCommandHistoryBase::writeConfig ()
#if DEBUG_KP_COMMAND_HISTORY
kdDebug () << "kpCommandHistoryBase::writeConfig()" << endl;
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupUndoRedo);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupUndoRedo);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingUndoMinLimit, undoMinLimit ());
cfg->writeEntry (kpSettingUndoMaxLimit, undoMaxLimit ());
diff --git a/kolourpaint/kpdocumentsaveoptions.cpp b/kolourpaint/kpdocumentsaveoptions.cpp
index 849863d7..3a95171c 100644
--- a/kolourpaint/kpdocumentsaveoptions.cpp
+++ b/kolourpaint/kpdocumentsaveoptions.cpp
@@ -243,14 +243,14 @@ bool kpDocumentSaveOptions::qualityIsInvalid () const
// public static
-TQString kpDocumentSaveOptions::defaultMimeType (KConfigBase *config)
+TQString kpDocumentSaveOptions::defaultMimeType (TDEConfigBase *config)
{
return config->readEntry (kpSettingForcedMimeType,
TQString::fromLatin1 ("image/png"));
}
// public static
-void kpDocumentSaveOptions::saveDefaultMimeType (KConfigBase *config,
+void kpDocumentSaveOptions::saveDefaultMimeType (TDEConfigBase *config,
const TQString &mimeType)
{
config->writeEntry (kpSettingForcedMimeType, mimeType);
@@ -258,7 +258,7 @@ void kpDocumentSaveOptions::saveDefaultMimeType (KConfigBase *config,
// public static
-int kpDocumentSaveOptions::defaultColorDepth (KConfigBase *config)
+int kpDocumentSaveOptions::defaultColorDepth (TDEConfigBase *config)
{
int colorDepth =
config->readNumEntry (kpSettingForcedColorDepth, -1);
@@ -273,27 +273,27 @@ int kpDocumentSaveOptions::defaultColorDepth (KConfigBase *config)
}
// public static
-void kpDocumentSaveOptions::saveDefaultColorDepth (KConfigBase *config, int colorDepth)
+void kpDocumentSaveOptions::saveDefaultColorDepth (TDEConfigBase *config, int colorDepth)
{
config->writeEntry (kpSettingForcedColorDepth, colorDepth);
}
// public static
-int kpDocumentSaveOptions::defaultDither (KConfigBase *config)
+int kpDocumentSaveOptions::defaultDither (TDEConfigBase *config)
{
return config->readBoolEntry (kpSettingForcedDither, initialDither ());
}
// public static
-void kpDocumentSaveOptions::saveDefaultDither (KConfigBase *config, bool dither)
+void kpDocumentSaveOptions::saveDefaultDither (TDEConfigBase *config, bool dither)
{
config->writeEntry (kpSettingForcedDither, dither);
}
// public static
-int kpDocumentSaveOptions::defaultQuality (KConfigBase *config)
+int kpDocumentSaveOptions::defaultQuality (TDEConfigBase *config)
{
int val = config->readNumEntry (kpSettingForcedQuality, -1);
if (qualityIsInvalid (val))
@@ -303,14 +303,14 @@ int kpDocumentSaveOptions::defaultQuality (KConfigBase *config)
}
// public static
-void kpDocumentSaveOptions::saveDefaultQuality (KConfigBase *config, int quality)
+void kpDocumentSaveOptions::saveDefaultQuality (TDEConfigBase *config, int quality)
{
config->writeEntry (kpSettingForcedQuality, quality);
}
// public static
-kpDocumentSaveOptions kpDocumentSaveOptions::defaultDocumentSaveOptions (KConfigBase *config)
+kpDocumentSaveOptions kpDocumentSaveOptions::defaultDocumentSaveOptions (TDEConfigBase *config)
{
kpDocumentSaveOptions saveOptions;
saveOptions.setMimeType (defaultMimeType (config));
@@ -326,7 +326,7 @@ kpDocumentSaveOptions kpDocumentSaveOptions::defaultDocumentSaveOptions (KConfig
}
// public static
-bool kpDocumentSaveOptions::saveDefaultDifferences (KConfigBase *config,
+bool kpDocumentSaveOptions::saveDefaultDifferences (TDEConfigBase *config,
const kpDocumentSaveOptions &oldDocInfo,
const kpDocumentSaveOptions &newDocInfo)
{
@@ -371,9 +371,9 @@ static TQStringList mimeTypesSupportingProperty (const TQString &property,
{
TQStringList mimeTypeList;
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
kpSettingsGroupMimeTypeProperties);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
if (cfg->hasKey (property))
{
diff --git a/kolourpaint/kpdocumentsaveoptionswidget.cpp b/kolourpaint/kpdocumentsaveoptionswidget.cpp
index b602494f..ebc68382 100644
--- a/kolourpaint/kpdocumentsaveoptionswidget.cpp
+++ b/kolourpaint/kpdocumentsaveoptionswidget.cpp
@@ -742,8 +742,8 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
this, TQT_SLOT (hidePreview ()));
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupPreviewSave);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupPreviewSave);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
if (cfg->hasKey (kpSettingPreviewSaveUpdateDelay))
{
@@ -769,8 +769,8 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
#if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
kdDebug () << "\tread cfg preview dialog last rel geometry" << endl;
#endif
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupPreviewSave);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupPreviewSave);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
m_previewDialogLastRelativeGeometry = cfg->readRectEntry (
kpSettingPreviewSaveGeometry);
@@ -845,8 +845,8 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
{
m_updatePreviewDialogLastRelativeGeometryTimer->stop ();
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupPreviewSave);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupPreviewSave);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingPreviewSaveGeometry, m_previewDialogLastRelativeGeometry);
cfg->sync ();
diff --git a/kolourpaint/kpmainwindow.h b/kolourpaint/kpmainwindow.h
index e47dc32b..9cfe947e 100644
--- a/kolourpaint/kpmainwindow.h
+++ b/kolourpaint/kpmainwindow.h
@@ -124,11 +124,11 @@ private:
// (only called for restoring a previous session e.g. starting KDE with
// a previously saved session; it's not called on normal KolourPaint
// startup)
- virtual void readProperties (KConfig *cfg);
+ virtual void readProperties (TDEConfig *cfg);
// (only called for saving the current session e.g. logging out of KDE
// with the KolourPaint window open; it's not called on normal KolourPaint
// exit)
- virtual void saveProperties (KConfig *cfg);
+ virtual void saveProperties (TDEConfig *cfg);
public:
~kpMainWindow ();
diff --git a/kolourpaint/kpmainwindow_help.cpp b/kolourpaint/kpmainwindow_help.cpp
index ecb17e13..ef87fda6 100644
--- a/kolourpaint/kpmainwindow_help.cpp
+++ b/kolourpaint/kpmainwindow_help.cpp
@@ -73,8 +73,8 @@ void kpMainWindow::enableHelpMenuDocumentActions (bool /*enable*/)
// SYNC: tdebase/twin/twinbindings.cpp
static TQString printScreenShortcutString ()
{
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), "Global Shortcuts");
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), "Global Shortcuts");
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
// TODO: i18n() entry name? twinbindings.cpp seems to but it doesn't
// make sense.
diff --git a/kolourpaint/kpmainwindow_image.cpp b/kolourpaint/kpmainwindow_image.cpp
index 7de1b158..6e54a7ad 100644
--- a/kolourpaint/kpmainwindow_image.cpp
+++ b/kolourpaint/kpmainwindow_image.cpp
@@ -317,8 +317,8 @@ void kpMainWindow::slotResizeScale ()
{
d->m_resizeScaleDialogLastKeepAspect = dialog.keepAspectRatio ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingResizeScaleLastKeepAspect,
d->m_resizeScaleDialogLastKeepAspect);
@@ -464,8 +464,8 @@ void kpMainWindow::slotMoreEffects ()
{
d->m_moreEffectsDialogLastEffect = dialog.selectedEffect ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingMoreEffectsLastEffect,
d->m_moreEffectsDialogLastEffect);
diff --git a/kolourpaint/kpmainwindow_settings.cpp b/kolourpaint/kpmainwindow_settings.cpp
index c4f339db..d3ca18f4 100644
--- a/kolourpaint/kpmainwindow_settings.cpp
+++ b/kolourpaint/kpmainwindow_settings.cpp
@@ -116,8 +116,8 @@ void kpMainWindow::slotShowPathToggled ()
slotUpdateCaption ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingShowPath, m_configShowPath);
cfg->sync ();
diff --git a/kolourpaint/kpmainwindow_text.cpp b/kolourpaint/kpmainwindow_text.cpp
index 44bea619..b0e406b5 100644
--- a/kolourpaint/kpmainwindow_text.cpp
+++ b/kolourpaint/kpmainwindow_text.cpp
@@ -77,8 +77,8 @@ void kpMainWindow::setupTextToolBarActions ()
// private
void kpMainWindow::readAndApplyTextSettings ()
{
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
m_actionTextFontFamily->setFont (cfg->readEntry (kpSettingFontFamily, TQString::fromLatin1 ("Times")));
m_actionTextFontSize->setFontSize (cfg->readNumEntry (kpSettingFontSize, 14));
@@ -141,8 +141,8 @@ void kpMainWindow::slotTextFontFamilyChanged ()
if (m_mainView)
m_mainView->setFocus ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingFontFamily, m_actionTextFontFamily->font ());
cfg->sync ();
@@ -174,8 +174,8 @@ void kpMainWindow::slotTextFontSizeChanged ()
if (m_mainView)
m_mainView->setFocus ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingFontSize, m_actionTextFontSize->fontSize ());
cfg->sync ();
@@ -199,8 +199,8 @@ void kpMainWindow::slotTextBoldChanged ()
if (m_toolText && m_toolText->hasBegun ())
m_toolText->slotBoldChanged (m_actionTextBold->isChecked ());
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingBold, m_actionTextBold->isChecked ());
cfg->sync ();
}
@@ -222,8 +222,8 @@ void kpMainWindow::slotTextItalicChanged ()
if (m_toolText && m_toolText->hasBegun ())
m_toolText->slotItalicChanged (m_actionTextItalic->isChecked ());
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingItalic, m_actionTextItalic->isChecked ());
cfg->sync ();
}
@@ -245,8 +245,8 @@ void kpMainWindow::slotTextUnderlineChanged ()
if (m_toolText && m_toolText->hasBegun ())
m_toolText->slotUnderlineChanged (m_actionTextUnderline->isChecked ());
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingUnderline, m_actionTextUnderline->isChecked ());
cfg->sync ();
}
@@ -268,8 +268,8 @@ void kpMainWindow::slotTextStrikeThruChanged ()
if (m_toolText && m_toolText->hasBegun ())
m_toolText->slotStrikeThruChanged (m_actionTextStrikeThru->isChecked ());
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupText);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingStrikeThru, m_actionTextStrikeThru->isChecked ());
cfg->sync ();
}
diff --git a/kolourpaint/kpmainwindow_tools.cpp b/kolourpaint/kpmainwindow_tools.cpp
index e4832f59..14a541df 100644
--- a/kolourpaint/kpmainwindow_tools.cpp
+++ b/kolourpaint/kpmainwindow_tools.cpp
@@ -392,8 +392,8 @@ void kpMainWindow::slotToolSelected (kpTool *tool)
// private
void kpMainWindow::readLastTool ()
{
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
m_lastToolNumber = cfg->readNumEntry (kpSettingLastTool, -1);
}
@@ -424,8 +424,8 @@ void kpMainWindow::saveLastTool ()
return;
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingLastTool, number);
cfg->sync ();
diff --git a/kolourpaint/kpmainwindow_view.cpp b/kolourpaint/kpmainwindow_view.cpp
index c90479b0..4a95255a 100644
--- a/kolourpaint/kpmainwindow_view.cpp
+++ b/kolourpaint/kpmainwindow_view.cpp
@@ -729,8 +729,8 @@ void kpMainWindow::slotShowGridToggled ()
updateMainViewGrid ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingShowGrid, m_configShowGrid = m_actionShowGrid->isChecked ());
cfg->sync ();
@@ -853,8 +853,8 @@ void kpMainWindow::slotSaveThumbnailGeometry ()
<< endl;
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingThumbnailGeometry, m_configThumbnailGeometry);
cfg->sync ();
@@ -869,8 +869,8 @@ void kpMainWindow::slotShowThumbnailToggled ()
m_configThumbnailShown = m_actionShowThumbnail->isChecked ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingThumbnailShown, m_configThumbnailShown);
cfg->sync ();
@@ -904,8 +904,8 @@ void kpMainWindow::slotZoomedThumbnailToggled ()
m_configZoomedThumbnail = m_actionZoomedThumbnail->isChecked ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingThumbnailZoomed, m_configZoomedThumbnail);
cfg->sync ();
@@ -923,8 +923,8 @@ void kpMainWindow::slotThumbnailShowRectangleToggled ()
d->m_configThumbnailShowRectangle = d->m_actionShowThumbnailRectangle->isChecked ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingThumbnailShowRectangle, d->m_configThumbnailShowRectangle);
cfg->sync ();
diff --git a/kolourpaint/pixmapfx/kpeffectflatten.cpp b/kolourpaint/pixmapfx/kpeffectflatten.cpp
index 471a3293..001fb7e6 100644
--- a/kolourpaint/pixmapfx/kpeffectflatten.cpp
+++ b/kolourpaint/pixmapfx/kpeffectflatten.cpp
@@ -137,8 +137,8 @@ kpEffectFlattenWidget::kpEffectFlattenWidget (bool actOnSelection,
{
if (!s_lastColor1.isValid () || !s_lastColor2.isValid ())
{
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupFlattenEffect);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupFlattenEffect);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
s_lastColor1 = cfg->readColorEntry (kpSettingFlattenEffectColor1);
if (!s_lastColor1.isValid ())
@@ -183,8 +183,8 @@ kpEffectFlattenWidget::~kpEffectFlattenWidget ()
s_lastColor2 = color2 ();
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupFlattenEffect);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (), kpSettingsGroupFlattenEffect);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingFlattenEffectColor1, s_lastColor1);
cfg->writeEntry (kpSettingFlattenEffectColor2, s_lastColor2);
diff --git a/kolourpaint/pixmapfx/kppixmapfx.cpp b/kolourpaint/pixmapfx/kppixmapfx.cpp
index 6525854a..a861995f 100644
--- a/kolourpaint/pixmapfx/kppixmapfx.cpp
+++ b/kolourpaint/pixmapfx/kppixmapfx.cpp
@@ -492,9 +492,9 @@ TQPixmap kpPixmapFX::convertToPixmapAsLosslessAsPossible (const TQImage &image,
int configDitherIfNumColorsGreaterThan = 323;
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
if (cfg->hasKey (kpSettingDitherOnOpen))
{
diff --git a/kolourpaint/widgets/kptooltoolbar.cpp b/kolourpaint/widgets/kptooltoolbar.cpp
index 56dde564..e33986c6 100644
--- a/kolourpaint/widgets/kptooltoolbar.cpp
+++ b/kolourpaint/widgets/kptooltoolbar.cpp
@@ -175,9 +175,9 @@ int kpToolToolBar::defaultIconSize ()
#endif
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
kpSettingsGroupTools);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
if (cfg->hasKey (kpSettingToolBoxIconSize))
{
diff --git a/kolourpaint/widgets/kptoolwidgetbase.cpp b/kolourpaint/widgets/kptoolwidgetbase.cpp
index 18177804..ae70a906 100644
--- a/kolourpaint/widgets/kptoolwidgetbase.cpp
+++ b/kolourpaint/widgets/kptoolwidgetbase.cpp
@@ -172,8 +172,8 @@ TQPair <int, int> kpToolWidgetBase::defaultSelectedRowAndCol () const
if (name ())
{
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
TQString nameString = TQString::fromLatin1 (name ());
@@ -215,8 +215,8 @@ void kpToolWidgetBase::saveSelectedAsDefault () const
if (!name ())
return;
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupTools);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
TQString nameString = TQString::fromLatin1 (name ());
cfg->writeEntry (nameString + TQString::fromLatin1 (" Row"), m_selectedRow);
diff --git a/kolourpaint/kpdocument.cpp b/kolourpaint/kpdocument.cpp
index 48eb6641..100bd5ce 100644
--- a/kolourpaint/kpdocument.cpp
+++ b/kolourpaint/kpdocument.cpp
@@ -247,7 +247,7 @@ TQPixmap kpDocument::getPixmapFromFile (const KURL &url, bool suppressDoesntExis
TQString tempFile;
- if (url.isEmpty () || !KIO::NetAccess::download (url, tempFile, parent))
+ if (url.isEmpty () || !TDEIO::NetAccess::download (url, tempFile, parent))
{
if (!suppressDoesntExistDialog)
{
@@ -262,7 +262,7 @@ TQPixmap kpDocument::getPixmapFromFile (const KURL &url, bool suppressDoesntExis
TQImage image;
// sync: remember to "KIO::NetAccess::removeTempFile (tempFile)" in all exit paths
{
TQString detectedMimeType = KImageIO::mimeType (tempFile);
if (saveOptions)
@@ -280,13 +280,13 @@ TQPixmap kpDocument::getPixmapFromFile (const KURL &url, bool suppressDoesntExis
KMessageBox::sorry (parent,
i18n ("Could not open \"%1\" - unknown mimetype.")
.arg (kpDocument::prettyFilenameForURL (url)));
- KIO::NetAccess::removeTempFile (tempFile);
+ TDEIO::NetAccess::removeTempFile (tempFile);
return TQPixmap ();
}
image = TQImage (tempFile);
- KIO::NetAccess::removeTempFile (tempFile);
+ TDEIO::NetAccess::removeTempFile (tempFile);
}
@@ -394,7 +394,7 @@ bool kpDocument::open (const KURL &url, bool newDocSameNameIfNotExist)
{
if (!url.isEmpty () &&
// not just a permission error?
- !KIO::NetAccess::exists (url, true/*open*/, m_mainWindow))
+ !TDEIO::NetAccess::exists (url, true/*open*/, m_mainWindow))
{
openNew (url);
}
@@ -619,7 +619,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
bool lossyPrompt,
TQWidget *parent)
{
// TODO: Use KIO::NetAccess:mostLocalURL() for accessing home:/ (and other
// such local URLs) for efficiency and because only local writes
// are atomic.
#if DEBUG_KP_DOCUMENT
@@ -632,7 +632,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
metaInfo.printDebug (TQString::fromLatin1 ("\tmetaInfo"));
#endif
- if (overwritePrompt && KIO::NetAccess::exists (url, false/*write*/, parent))
+ if (overwritePrompt && TDEIO::NetAccess::exists (url, false/*write*/, parent))
{
int result = KMessageBox::warningContinueCancel (parent,
i18n ("A document called \"%1\" already exists.\n"
@@ -773,7 +773,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
// TODO: No one seems to know how to do this atomically
// [http://lists.kde.org/?l=kde-core-devel&m=117845162728484&w=2].
// At least, fish:// (ssh) is definitely not atomic.
- if (!KIO::NetAccess::upload (filename, url, parent))
+ if (!TDEIO::NetAccess::upload (filename, url, parent))
{
#if DEBUG_KP_DOCUMENT
kdDebug () << "\treturning false because could not upload" << endl;
@@ -849,7 +849,7 @@ bool kpDocument::isFromURL (bool checkURLStillExists) const
return true;
return (!m_url.isEmpty () &&
- KIO::NetAccess::exists (m_url, true/*open*/, m_mainWindow));
+ TDEIO::NetAccess::exists (m_url, true/*open*/, m_mainWindow));
}
@@ -262,7 +262,7 @@ TQPixmap kpDocument::getPixmapFromFile (const KURL &url, bool suppressDoesntExis
TQImage image;
- // sync: remember to "KIO::NetAccess::removeTempFile (tempFile)" in all exit paths
+ // sync: remember to "TDEIO::NetAccess::removeTempFile (tempFile)" in all exit paths
{
TQString detectedMimeType = KImageIO::mimeType (tempFile);
@@ -619,7 +619,7 @@ bool kpDocument::savePixmapToFile (const TQPixmap &pixmap,
TQWidget *parent)
{
- // TODO: Use KIO::NetAccess:mostLocalURL() for accessing home:/ (and other
+ // TODO: Use TDEIO::NetAccess:mostLocalURL() for accessing home:/ (and other
// such local URLs) for efficiency and because only local writes
// are atomic.
diff --git a/kolourpaint/kpdocumentsaveoptions.h b/kolourpaint/kpdocumentsaveoptions.h
index d6279885..b937f5e3 100644
--- a/kolourpaint/kpdocumentsaveoptions.h
+++ b/kolourpaint/kpdocumentsaveoptions.h
@@ -33,7 +33,7 @@
class TQPixmap;
class TQString;
-class KConfigBase;
+class TDEConfigBase;
class kpDocumentSaveOptions
@@ -84,24 +84,24 @@ public:
// (All assume that <config>'s group has been set)
- // (None of them call KConfigBase::reparseConfig() nor KConfigBase::sync())
+ // (None of them call TDEConfigBase::reparseConfig() nor TDEConfigBase::sync())
- static TQString defaultMimeType (KConfigBase *config);
- static void saveDefaultMimeType (KConfigBase *config, const TQString &mimeType);
+ static TQString defaultMimeType (TDEConfigBase *config);
+ static void saveDefaultMimeType (TDEConfigBase *config, const TQString &mimeType);
- static int defaultColorDepth (KConfigBase *config);
- static void saveDefaultColorDepth (KConfigBase *config, int colorDepth);
+ static int defaultColorDepth (TDEConfigBase *config);
+ static void saveDefaultColorDepth (TDEConfigBase *config, int colorDepth);
- static int defaultDither (KConfigBase *config);
- static void saveDefaultDither (KConfigBase *config, bool dither);
+ static int defaultDither (TDEConfigBase *config);
+ static void saveDefaultDither (TDEConfigBase *config, bool dither);
- static int defaultQuality (KConfigBase *config);
- static void saveDefaultQuality (KConfigBase *config, int quality);
+ static int defaultQuality (TDEConfigBase *config);
+ static void saveDefaultQuality (TDEConfigBase *config, int quality);
- static kpDocumentSaveOptions defaultDocumentSaveOptions (KConfigBase *config);
+ static kpDocumentSaveOptions defaultDocumentSaveOptions (TDEConfigBase *config);
// (returns true if it encountered a difference (and saved it to <config>))
- static bool saveDefaultDifferences (KConfigBase *config,
+ static bool saveDefaultDifferences (TDEConfigBase *config,
const kpDocumentSaveOptions &oldDocInfo,
const kpDocumentSaveOptions &newDocInfo);
diff --git a/kolourpaint/kpmainwindow.cpp b/kolourpaint/kpmainwindow.cpp
index 439f99c4..b073e01e 100644
--- a/kolourpaint/kpmainwindow.cpp
+++ b/kolourpaint/kpmainwindow.cpp
@@ -103,8 +103,8 @@ double kpMainWindow::configColorSimilarity () const
// public
void kpMainWindow::configSetColorSimilarity (double val)
{
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingColorSimilarity, m_configColorSimilarity = val);
cfg->sync ();
@@ -118,8 +118,8 @@ void kpMainWindow::readGeneralSettings ()
kdDebug () << "\tkpMainWindow(" << name () << ")::readGeneralSettings()" << endl;
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
m_configFirstTime = cfg->readBoolEntry (kpSettingFirstTime, true);
m_configShowGrid = cfg->readBoolEntry (kpSettingShowGrid, false);
@@ -147,8 +147,8 @@ void kpMainWindow::readThumbnailSettings ()
kdDebug () << "\tkpMainWindow(" << name () << ")::readThumbnailSettings()" << endl;
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupThumbnail);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
m_configThumbnailShown = cfg->readBoolEntry (kpSettingThumbnailShown, false);
m_configThumbnailGeometry = cfg->readRectEntry (kpSettingThumbnailGeometry);
@@ -206,7 +206,7 @@ void kpMainWindow::init ()
// read config
//
// KConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
kapp->config ()->reparseConfiguration ();
#if DEBUG_KP_MAIN_WINDOW
@@ -298,8 +298,8 @@ void kpMainWindow::init ()
m_toolToolBar->setBarPos (KToolBar::Left);
m_colorToolBar->setBarPos (KToolBar::Bottom);
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingFirstTime, m_configFirstTime = false);
cfg->sync ();
@@ -312,7 +312,7 @@ void kpMainWindow::init ()
// private virtual [base KMainWindow]
-void kpMainWindow::readProperties (KConfig *cfg)
+void kpMainWindow::readProperties (TDEConfig *cfg)
{
#if DEBUG_KP_MAIN_WINDOW
kdDebug () << "kpMainWindow<" << this << ">::readProperties()" << endl;
@@ -366,7 +366,7 @@ void kpMainWindow::readProperties (KConfig *cfg)
// private virtual [base KMainWindow]
// WARNING: KMainWindow API Doc says "No user interaction is allowed
// in this function!"
-void kpMainWindow::saveProperties (KConfig *cfg)
+void kpMainWindow::saveProperties (TDEConfig *cfg)
{
#if DEBUG_KP_MAIN_WINDOW
kdDebug () << "kpMainWindow<" << this << ">::saveProperties()" << endl;
@@ -206,7 +206,7 @@ void kpMainWindow::init ()
// read config
//
- // KConfig::readEntry() does not actually reread from disk, hence doesn't
+ // TDEConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
kapp->config ()->reparseConfiguration ();
diff --git a/kolourpaint/kpmainwindow_file.cpp b/kolourpaint/kpmainwindow_file.cpp
index 5c6897c2..c962d3eb 100644
--- a/kolourpaint/kpmainwindow_file.cpp
+++ b/kolourpaint/kpmainwindow_file.cpp
@@ -146,9 +146,9 @@ void kpMainWindow::addRecentURL (const KURL &url)
return;
- KConfig *cfg = kapp->config ();
+ TDEConfig *cfg = kapp->config ();
- // KConfig::readEntry() does not actually reread from disk, hence doesn't
+ // TDEConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
cfg->reparseConfiguration ();
@@ -230,12 +230,12 @@ void kpMainWindow::slotNew ()
// private
TQSize kpMainWindow::defaultDocSize () const
{
// KConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
kapp->config ()->reparseConfiguration ();
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
TQSize docSize = cfg->readSizeEntry (kpSettingLastDocSize);
@@ -261,8 +261,8 @@ void kpMainWindow::saveDefaultDocSize (const TQSize &size)
kdDebug () << "\tCONFIG: saving Last Doc Size = " << size << endl;
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), kpSettingsGroupGeneral);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
cfg->writeEntry (kpSettingLastDocSize, size);
cfg->sync ();
@@ -599,7 +599,7 @@ KURL kpMainWindow::askForSaveURL (const TQString &caption,
bool reparsedConfiguration = false;
// KConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
// so reparseConfiguration() must be called
#define SETUP_READ_CFG() \
@@ -609,8 +609,8 @@ KURL kpMainWindow::askForSaveURL (const TQString &caption,
reparsedConfiguration = true; \
} \
\
- KConfigGroupSaver cfgGroupSaver (kapp->config (), forcedSaveOptionsGroup); \
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), forcedSaveOptionsGroup); \
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
if (chosenSaveOptions)
@@ -715,8 +715,8 @@ KURL kpMainWindow::askForSaveURL (const TQString &caption,
newSaveOptions.printDebug ("\tnewSaveOptions");
#endif
- KConfigGroupSaver cfgGroupSaver (kapp->config (), forcedSaveOptionsGroup);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigGroupSaver cfgGroupSaver (kapp->config (), forcedSaveOptionsGroup);
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
// Save options user forced - probably want to use them in future
kpDocumentSaveOptions::saveDefaultDifferences (cfg,
@@ -921,7 +921,7 @@ bool kpMainWindow::slotReload ()
// If it's _supposed to_ come from a URL or it exists
if (m_document->isFromURL (false/*don't bother checking exists*/) ||
- (!oldURL.isEmpty () && KIO::NetAccess::exists (oldURL, true/*open*/, this)))
+ (!oldURL.isEmpty () && TDEIO::NetAccess::exists (oldURL, true/*open*/, this)))
{
#if DEBUG_KP_MAIN_WINDOW
kdDebug () << "kpMainWindow::slotReload() reloading from disk!" << endl;
@@ -997,9 +997,9 @@ static bool shouldPrintImageCenteredOnPage ()
#endif
bool ret;
- KConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
+ TDEConfigGroupSaver cfgGroupSaver (TDEGlobal::config (),
kpSettingsGroupGeneral);
- KConfigBase *cfg = cfgGroupSaver.config ();
+ TDEConfigBase *cfg = cfgGroupSaver.config ();
if (cfg->hasKey (kpSettingPrintImageCenteredOnPage))
{
@@ -230,12 +230,12 @@ void kpMainWindow::slotNew ()
TQSize kpMainWindow::defaultDocSize () const
{
- // KConfig::readEntry() does not actually reread from disk, hence doesn't
+ // TDEConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
kapp->config ()->reparseConfiguration ();
@@ -599,7 +599,7 @@ KURL kpMainWindow::askForSaveURL (const TQString &caption,
bool reparsedConfiguration = false;
- // KConfig::readEntry() does not actually reread from disk, hence doesn't
+ // TDEConfig::readEntry() does not actually reread from disk, hence doesn't
// realise what other processes have done e.g. Settings / Show Path
// so reparseConfiguration() must be called